'use strict';

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports.summary = summary;
exports.prettyPrintHeader = prettyPrintHeader;
exports.clockoutSummary = clockoutSummary;
exports.prettyPrintEntry = prettyPrintEntry;

var _convertSeconds = require('convert-seconds');

var _convertSeconds2 = _interopRequireDefault(_convertSeconds);

var _simpleZeropad = require('simple-zeropad');

var _simpleZeropad2 = _interopRequireDefault(_simpleZeropad);

var _pendel = require('pendel');

var _pendel2 = _interopRequireDefault(_pendel);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

/**
 * Error messages.
 *
 */
var errors = {
	noTimeCard: '\n  ' + _chalk2['default'].bgRed(' TIMECARD ERROR ') + _chalk2['default'].bold.white(' Your ') + _chalk2['default'].cyan('.timecard.json') + _chalk2['default'].white(' does not exist. Did you delete or rename it?\n  ') + _chalk2['default'].bold.white('Tip:') + ' Create a timecard by typing ' + _chalk2['default'].cyan('timecard new') + '\n',
	invalidTimeCardJSON: '\n  ' + _chalk2['default'].bgRed(' TIMECARD ERROR ') + _chalk2['default'].bold.white(' Your ') + _chalk2['default'].cyan('.timecard.json') + _chalk2['default'].white(' file appears to be invalid json. Did you edit manually?\n  ') + _chalk2['default'].gray('Please correct the JSON error before using timecard. \n'),
	noTimeCardFoundForClockout: '\n  ' + _chalk2['default'].bgRed(' TIMECARD ERROR ') + _chalk2['default'].bold.white(' You must create a timecard before clocking out. \n  ') + _chalk2['default'].bold.white('Tip:') + ' Create a timecard by typing ' + _chalk2['default'].cyan('timecard new') + ' or ' + _chalk2['default'].cyan('timecard clockin') + '\n',
	noTimeCardFoundForPrint: '\n  ' + _chalk2['default'].bgRed(' TIMECARD ERROR ') + _chalk2['default'].bold.white(' You must have a timecard before printing. \n  ') + _chalk2['default'].bold.white('Tip:') + ' Create a timecard by typing ' + _chalk2['default'].cyan('timecard new') + ' and clockin with ' + _chalk2['default'].cyan('timecard clockin') + '\n',
	clockOutIsPending: '\n  ' + _chalk2['default'].bgRed(' TIMECARD ERROR ') + _chalk2['default'].bold.white(' You must clockout before clocking in. \n  ') + _chalk2['default'].bold.white('Tip:') + ' Clock out by typing ' + _chalk2['default'].cyan('timecard clockout') + ', or edit the timecard file manually. \n',
	noClockInFound: '\n  ' + _chalk2['default'].bgRed(' TIMECARD ERROR ') + _chalk2['default'].bold.white(' You must clockin before clocking out. \n  ') + _chalk2['default'].bold.white('Tip:') + ' Clock in by typing ' + _chalk2['default'].cyan('timecard clockin') + ', or edit the timecard file manually. \n'
};

exports.errors = errors;
/**
 * General messages.
 *
 */
var messages = {
	createdNewTimeCard: '\n  ' + _chalk2['default'].bgCyan.black(' TIMECARD ') + _chalk2['default'].bold.white(' You have created a new timecard file. \n') + _chalk2['default'].bold.white('  Tip:') + ' Use the ' + _chalk2['default'].cyan('clockin') + ' and ' + _chalk2['default'].cyan('clockout') + ' commands to record your time.\n',
	successfulClockin: '\n  ' + _chalk2['default'].bgCyan.black(' TIMECARD ') + _chalk2['default'].bold.white(' You have ') + _chalk2['default'].bold.green('clocked in: ') + time() + '\n',
	successfulClockout: '\n  ' + _chalk2['default'].bgCyan.black(' TIMECARD ') + _chalk2['default'].bold.white(' You have ') + _chalk2['default'].bold.red('clocked out: ') + time() + '\n',
	prettyPrintBorder: _chalk2['default'].gray('\n  _________________________________________________________________')
};

exports.messages = messages;
/**
 * A Helper function to generate the total time data.
 *
 * @note: This prints the total hours/mins/secs on the
 * bottom when the user types `timecard print`.
 *
 * @param {number} seconds - the number of seconds recorded in the timecard project.
 */

function summary(seconds) {
	var total = (0, _convertSeconds2['default'])(seconds);
	var timeStr = makeTimeString(total);

	return '\n\n  ' + _chalk2['default'].cyan('Total Time: ') + ' ' + _chalk2['default'].gray(timeStr) + ' \n  ' + total.hours + ' ' + _chalk2['default'].white('Hours') + ' ' + total.minutes + ' ' + _chalk2['default'].white('Minutes') + ' ' + total.seconds + ' ' + _chalk2['default'].white('Seconds');
}

function prettyPrintHeader() {
	var projectName = this.name;
	return '\n  ' + _chalk2['default'].bgCyan.black(' TIMECARD ') + ' ' + _chalk2['default'].cyan(' Logged Hours ') + '\n  ' + _chalk2['default'].gray('Project:') + ' ' + _chalk2['default'].gray(projectName) + ' \n  ' + messages.prettyPrintBorder + '\n\n';
}

function clockoutSummary(shiftSeconds, totalSeconds) {
	var total = (0, _convertSeconds2['default'])(totalSeconds);
	var shift = (0, _convertSeconds2['default'])(shiftSeconds);
	var totalStr = makeTimeString(total);
	var shiftStr = makeTimeString(shift);

	return '\n  ' + _chalk2['default'].cyan('Total Shift Time:') + ' ' + _chalk2['default'].gray(shiftStr) + '\n  ' + _chalk2['default'].cyan('Total Project Time:') + ' ' + _chalk2['default'].gray(totalStr);
}

/**
 * Pretty-print the timecard data.
 *
 * @param {number} shiftId - the shiftId value
 * @param {object} timeobj - the timecard data object
 */

function prettyPrintEntry(shiftId, shift) {
	var startTime = shift.startTime;
	var startTimeOnly;
	var startDateOnly;
	var endTime = shift.endTime;
	var endTimeOnly;
	var endDateOnly;
	var time;

	if (startTime) {
		startTimeOnly = timeOnly(startTime);
		startDateOnly = dateOnly(startTime);
	}

	if (endTime) {
		endTimeOnly = timeOnly(endTime);
		endDateOnly = dateOnly(endTime);
	}

	if (startTime && endTime) {
		time = makeTimeString(_pendel2['default'].time(startTime, endTime));
		var output = '  ' + _chalk2['default'].gray(shiftId) + ' ' + _chalk2['default'].white(startDateOnly) + ' ' + _chalk2['default'].cyan(startTimeOnly) + ' - ' + _chalk2['default'].white(endDateOnly) + ' ' + _chalk2['default'].cyan(endTimeOnly) + ' ' + _chalk2['default'].gray('[') + time + _chalk2['default'].gray(']') + '\n';

		if (shift.messages.length > 0) {
			shift.messages.forEach(function (message) {
				output += '      - ' + message + '\n';
			});
		}
		return output;
	}
	return '  ' + _chalk2['default'].gray(shiftId) + ' ' + _chalk2['default'].white(startDateOnly) + ' ' + _chalk2['default'].cyan(startTimeOnly) + ' - ' + _chalk2['default'].gray('[clockout pending]') + '\n';
}

/**
 * Extract the Date portion from Datestring
 * 'Tue Feb 14 2017 17:31:04 GMT+0000 (WET)' => 'Tue Feb 14 2017'
 * @param {string} string - the datetime string
 * @returns {string}
 */
function dateOnly(string) {
	return string.substring(0, 15);
}

/**
 * Extract the Date portion from Datestring
 * 'Tue Feb 14 2017 17:31:04 GMT+0000 (WET)' => '17:31:04'
 * @param {string} string - the datetime string
 * @returns {string}
 */
function timeOnly(string) {
	return string.substring(16, 24);
}

/**
 * Get the current time in the format: 'Wed Apr 09 2015'
 *
 * @returns {string}
 */
function time() {
	var date = new Date().toString();
	return date.slice(16, 24);
}

/**
 * Make a timestring in the format of '00:00:00'
 *
 * @param {object} timeObj - the duration object returned by pendel.
 * @returns {string}
 */
function makeTimeString(timeObj) {
	return (0, _simpleZeropad2['default'])(timeObj.hours) + ':' + (0, _simpleZeropad2['default'])(timeObj.minutes) + ':' + (0, _simpleZeropad2['default'])(timeObj.seconds);
}