'use strict';

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _Promise = require('babel-runtime/core-js/promise')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.getTotalSeconds = getTotalSeconds;
exports.getPendingClockoutId = getPendingClockoutId;
exports.getShiftOrder = getShiftOrder;
exports.getNewShift = getNewShift;
exports.stringOrUndefined = stringOrUndefined;
exports.getNextShiftId = getNextShiftId;
exports.writeTimeCard = writeTimeCard;
exports.getTimeCard = getTimeCard;
exports.blankTimecard = blankTimecard;
exports.isTimeCardValid = isTimeCardValid;
exports.getTimecardString = getTimecardString;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _pendel = require('pendel');

var _pendel2 = _interopRequireDefault(_pendel);

var _trim = require('trim');

var _trim2 = _interopRequireDefault(_trim);

/**
 * Count the Total Seconds in all the shifts
 * @param {object} shifts - the shifts object you want to check
 */

function getTotalSeconds(shifts) {
  var seconds = 0;
  _Object$keys(shifts).forEach(function (shiftId) {
    var shift = shifts[shiftId];
    if (shift.startTime && shift.endTime) {
      seconds += _pendel2['default'].date(shift.startTime, shift.endTime).seconds;
    }
  });
  return seconds;
}

/**
 * Check for a pending clockout.
 * @param {object} shifts - The shifts object you want to check
 * @returns {string|undefined}
 */

function getPendingClockoutId(shifts) {
  var pendingIds = _Object$keys(shifts).filter(function (shiftId) {
    var shift = shifts[shiftId];
    return shift.startTime && !shift.endTime;
  });

  if (pendingIds.length > 0) {
    return pendingIds.pop();
  }
  return undefined;
}

/**
 * Get an array of shift ids in order
 * @param {object} shifts - The shifts object you want to order
*/

function getShiftOrder(shifts) {
  return _Object$keys(shifts).sort(function (a, b) {
    return parseInt(a, 10) - parseInt(b, 10);
  });
}

/**
 * Get a new shift object.
 *
 * @param {string} _message - an optional message to include on the shift
*/

function getNewShift(_message) {
  var messages = [];

  var message = this.stringOrUndefined(_message);

  if (message) {
    messages.push(message);
  }

  var date = new Date();
  return {
    startTime: date.toString(),
    messages: messages
  };
}

/**
 * Get a trimmed string or undefined.
 *
 * @param {string|undefined} value - The value to check for string or undefined.
 * @returns {number}
*/

function stringOrUndefined(value) {
  if (!value) {
    return undefined;
  }

  if (typeof value === 'string') {
    var trimmed = (0, _trim2['default'])(value);

    if (trimmed.length === 0) {
      return undefined;
    }
    return trimmed;
  }
}

/**
 * Get the next shift id.
 *
 * @param {object} timecard - The timecard object to use.
 * @returns {number}
*/

function getNextShiftId(timecard) {
  var self = timecard;

  var lastShiftId = self.shiftOrder.length > 0 ? parseInt(self.shiftOrder[self.shiftOrder.length - 1], 10) : 0;
  return lastShiftId + 1;
}

/**
 * Physically write the timecard data to the json file.
 *
 * @param {string} path - the path to write the file to
 * @param {object} data - the json data to write
 */

function writeTimeCard(path, data) {
  return new _Promise(function (resolve, reject) {
    _fs2['default'].writeFile(path, data, function (err) {
      if (err) {
        reject(err);
      } else {
        resolve();
      }
    });
  });
}

/**
 * Read the .timecard.json file from disk and return its contents
 *
 * @param {string} filepath - the filepath to look for a timecard file.
 * @returns {*} Promise
 */

function getTimeCard(filepath) {
  var timecardData = this.blankTimecard(filepath);

  return new _Promise(function (resolve, reject) {
    try {
      timecardData = _fs2['default'].readFileSync(filepath, 'utf8');
    } catch (err) {
      if (err.code !== 'ENOENT') {
        reject(err);
      }
    }
    resolve(timecardData);
  });
}

/**
 * Get a blank timecard object.
 *
 * @param {string} name - the project name to feed the timecard object
 * @returns {string}
 */

function blankTimecard(name) {
  var blank = {
    project: name,
    shifts: {},
    totals: {
      hours: 0,
      minutes: 0,
      seconds: 0
    }
  };
  return JSON.stringify(blank, null, 2);
}

/**
 * Check if .timecard.json is in a valid json format.
 *
 * @returns {*} Promise
 */

function isTimeCardValid(timecardJson) {
  var data = undefined;

  if (typeof timecardJson === 'string') {
    try {
      data = JSON.parse(timecardJson);
    } catch (err) {
      return false;
    }
  }

  if (typeof timecardJson === 'object') {
    data = timecardJson;
  }

  return data.project && data.shifts && data.totals && true;
}

/**
 * Create a Timecard object for saving.
 *
 * @param {object} timecard - the Timecard instance
 * @returns {string}
 */

function getTimecardString(timecard) {
  var obj = {
    project: timecard.name,
    shifts: timecard.shifts || {},
    totals: timecard.totals || { hours: 0, minutes: 0, seconds: 0 }
  };
  return JSON.stringify(obj, null, 2);
}